#
# spec file for package mlmmj
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mlmmj
Version:        1.2.19.0
Release:        3.1
Summary:        Mail Server Independent Reimplementation of the EZMLM Mailing List
License:        MIT
Group:          Productivity/Networking/Email/Mailinglists
Url:            http://mlmmj.org/
Source0:        http://mlmmj.org/releases/%{name}-%{version}.tar.bz2
Source1:        mlmmj-rpmlintrc
BuildRequires:  fdupes
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is an attempt at implementing a mailing list manager with the same
functionality as EZMLM, but with the MIT/X11 license and no mail server
dependency.

%prep
%setup -q

%build
%configure --enable-receive-strip
make CFLAGS="%{optflags} -fstack-protector" %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
mkdir -p %{buildroot}%{_datadir}/%{name}/contrib
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}/examples
cp -a contrib/{amime-receive,web} %{buildroot}%{_defaultdocdir}/%{name}/examples/
cp -a contrib/receivestrip/README README.receivestrip
cp -a README* FAQ UPGRADE LICENSE AUTHORS ChangeLog TUNABLES %{buildroot}%{_defaultdocdir}/%{name}/
%fdupes %{buildroot}

%files
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/*
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/%{name}

%changelog
* Fri Feb  9 2018 suse-beta@cboltz.de
- drop iconv call to avoid double-utf8-encoding of the mail templates
  (poo#31546)
* Mon Jul 24 2017 tchvatal@suse.com
- Run over with spec-cleaner
- Do not require recode and use iconv for conversions wrt fate#323644
* Mon May 25 2015 mrueckert@suse.de
- update to 1.2.19.0
  o Add README.footers and footer-related resources
  o Support ESMTP so OpenSMTPD uses 8 bits (Paul Fariello)
  o Use iconv to convert unknown character sets
  o Handle unfolded header lines better
  o Add a tunable for moderation request lifetime (Timo Boettcher)
  o Ensure mlmmj-send always honours tunables (e.g. relayhost)
  o Fix reason in denial messages for mails without the list in To:
    or CC:
- mlmmj-rpmlintrc
  - removed line about arch dependent files
* Mon Jul 14 2014 hvogel@suse.com
- Don't require fdupes on <SLE11
* Mon Mar 24 2014 ct@kki.org
- update to version 1.2.18.1
  o simply fixes three bugs, one of which caused mail to be lost,
    so everybody currently running 1.2.18.0 is encouraged to upgrade.
* Sat Jan 25 2014 aj@ajaissle.de
- Updated source url
* Wed Dec  4 2013 lars@linux-schulserver.de
- Update to version 1.2.18.0:
  o Richer list texts (including a new naming scheme, conditionals,
    automatic wrapping and true UTF-8 support).
    See README.listtexts for more details.
  o Notifying posters when their posts are being moderated
    (notifymod tunable).
  o Not-me-too feature to avoid having the poster receiving their
    own messages (notmetoo tunable).
  o Ability to explicitly reject posts (exposed in new list texts).
  o Ability to explicitly obstruct subscriptions
    (exposed in new list texts).
  o Unsubscribe from all versions of a list at once (changed behaviour
    of +unsubscribe[-{digest|nomail}]; they now all remove the
    subscriber from all versions of the list).
  o Ability to switch between different versions of a list by
    using +subscribe[-{digest|nomail|both}] ('both' means normal and
    digest, and is a 'hidden feature' not mentioned in the supplied
    list texts).
  o Subscription ability in php-admin.
- built mlmmj-receive-strip in contrib directory
- move /usr/share/mlmmj/contrib to /usr/share/doc/package/mlmmj/examples
  where it fits better (according to rpmlint)
- addded rpmlintrc to exclude the examples
* Tue Nov 16 2010 hvogel@novell.com
- Update to version 1.2.17.1
  o Check return status in mlmmj-perl-admin when adding subscribers
  o Better validation of input in php-admin
  o Added Turkish translation
  o Fixed security bug in mlmmj-php-admin
  o Added README.postfix to distribution tarball
  o Added contrib/amime-receive
  o Fixed memory leak in substitute_one()
  o Updated German listtexts
  o Updated TUNABLES file
* Tue Apr  6 2010 hvogel@novell.com
- Update to version 1.2.17
  o Added ifmodsendonlymodmoderate tunable
  o Replaced class.FastTemplate.php with class.rFastTemplate.php in
  contrib/web/php-admin (Christoph Thiel)
  o Added information about digest and nomail to listhelp
  o Fixed bug in mlmmj-maintd which caused loss of archive files
  in some requeue cases (Robin H. Johnson)
  o Added README.postfix (Jeremy Hinegardner, Andreas Schneider)
  o Added support for digest and nomail to +list (Christoph Wilke)
  o Caseinsensitive string compare for owner addr when +list is
  invoked. Spotted by Pavel Kolar.
  o Added contrib/web/php-moderation (Thomas Goirand)
* Wed Aug  5 2009 hvogel@suse.de
- Update to 1.2.16
  o Updated Dutch listtexts
  o Updated Italian listtexts
  o Added Postfix pipe backend support
  o Added support for static bounce addresses
  o Added a sanity check in mlmmj-receive-strip
  o Added miscellaneous sanity checks
  o Disabled digest mails when 'noarchive' is set
  o Added Russian listtexts
  o Fixed mmap()ing of zero-sized files
  o Fixed mlmmj-recieve [sic] for architectures where
    sizeof(int) and sizeof(char *) differ
  o Added support for the 'originalmail' keyword
* Fri Nov  9 2007 hvogel@suse.de
- make deny mails more verbose
* Tue Jul 31 2007 hvogel@suse.de
- Update to 1.2.15
  o Added --enable-recieve-strip configure option
  o Added unicode support to listtexts
  o Fixed build outside the source directory
  o Moved English listtexts and install all languages
  o Fixed missing exit()s in case of failed execl() calls
  o Changed Message-ID headers to include FQDN
  o Added support for 'discard' keyword in access rules
- fdupe installed files
* Wed May  2 2007 dbahi@suse.de
- added mlmmj-1.2.14-discard.patch
  * Implemented discard for the access rules to be able to
    drop unwanted mails without notification
* Tue Apr 17 2007 hvogel@suse.de
- update to version 1.2.14
  * Fixed a small memory leak in log_oper() log rotation
  * Added contrib/recievestrip/ MIME processor (Sascha Sommer)
  * Fixed digest multipart boundary (Thanks to Ulrich Mueller)
  * Added support for mail size limit (Christoph Wilke)
  * Ignore empty lines in control files
- droppend patches:
  * mlmmj-1.2.13-find_email_adr.patch <- upstream
  * mlmmj-log.patch <- upstream
- add more and recode listtexts to utf8
* Mon Mar 26 2007 hvogel@suse.de
- Fix to/cc parsing of addresses with brackets and quotations
  * mlmmj-1.2.13-find_email_adr.patch
* Thu Jan 25 2007 hvogel@suse.de
- log access output to operation log and not to the general log
* Wed Jan 10 2007 hvogel@suse.de
- Update to version 1.2.13
- drop patches because they are included
  * mlmmj-defaulttextdir.patch
  * mlmmj-faq.patch
  * mlmmj-nodigestsub.patch
  * mlmmj-nonomailsub.patch
  * mlmmj-send_help-generic.patch
- Sascha reworked the log patch to include the from address when
  mails are denied and display the correct access rule
* Thu Nov 16 2006 hvogel@suse.de
- Update to final 1.2.12 which fixes a double free with headers
  containing a = [#220552]
- drop gethdrline patch because its included
* Fri Nov 10 2006 hvogel@suse.de
- fix header unfolding. gethdrline() did not handle end-of-file in
  headers correct [#219497]
* Mon Oct 23 2006 hvogel@suse.de
- update to RC4 from 1.2.12
  o Fixed memory leak in checkwait_smtpreply()
  o Changed mlmmj-process to look at environment variable DEFAULT
    instead of EXT for qmail (Fabio Busatto)
  o Added Frensh listtext unsub-confirm-digest
  o Fixed EOF handling in checkwait_smtpreply()
  o Fixed header unfolding in gethdrline()
  o Changed German listtexts
  o Changed English listtexts
  o Changed chomp() to also remove CR from CRLF sequences
- add default listtext dir
* Wed Sep  6 2006 hvogel@suse.de
- split patches better
- include listtexts
- add nonomail tuneable
* Wed Sep  6 2006 ssommer@suse.de
- use the send_help function to send faq, help, nodigestsub texts
* Wed Sep  6 2006 ssommer@suse.de
- updated to mlmmj-1.2.12-RC1
- updated patches to use the new logging functions
* Thu Aug  3 2006 mskibbe@suse.de
- add patch that provides more information at logging
* Mon Jul 10 2006 hvogel@suse.de
- Make it possible to disable digest subscription
- Fix inclusion of listfaq text
* Fri Jun 23 2006 hvogel@suse.de
- Add faq patch to be able to have listname+faq
* Mon Apr 10 2006 mrueckert@suse.de
- added mlmmj-1.2.11_subscriber_mmap.patch:
  * src/subscriberfuncs.c: Do not mmap() 0 byte files.
    mmap() returns EINVAL for 0 byte size.
* Fri Jan 27 2006 mmj@suse.de
- Add missing %%endif
* Fri Jan 27 2006 mmj@suse.de
- Only use -fstack-protector where it exists
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 mmj@suse.de
- Update to 1.2.11 which is a pure bugfix release:
  o Previous fix to find_email_adr() was incomplete, so in some
  cases mails would get rejected due to the To: or Cc: rule
  o Sanity check to make sure there's a '@' in listaddress
* Wed Jan 18 2006 mmj@suse.de
- Compile with -fstack-protector
* Tue Jan 17 2006 mmj@suse.de
- Update to 1.2.10 including since 1.2.9:
  o Fix nasty bug in the new 1.2.9 find_email_adr() making comma in
  quoted text in From: being discarded as invalid
  o Simply make all addresses lowercase before doing anything else
  wrt. sub/unsub and bounce
  o Add czech listtexts
  o Make non list emails (subconf, moderation etc.) also honor
  relayhost and smtpport
  o Add tunable to be able to close for subscription only (closedlistsub)
* Wed Dec 14 2005 mmj@suse.de
- Update to 1.2.9 including since 1.2.8:
  o Make find_email_adr() more robust
  o Make the email address check case-insensitive
  o Add spanish listtext translations
  o Make recipient delimiter configurable per list
  o Added italian list texts translation.
  o Use is_subbed_in instead of find_subscriber when subscribing
  people
  o Make it possible to confirm subscription even though it's a
  closedlist. It makes sense to be able to confirm a request
  submitted by the sysadmin on the commandline
  o Add 'subonlyget' tunable which makes +get-N only work for
  subscribers
* Mon Jun 20 2005 mmj@suse.de
- Update to 1.2.8 which is a bugfix release (almost):
  o Don't closedir() before done
  o Make sure the resend of queue files will not loop indefinately
  o Make Date: header RFC2822 compliant
  o Add -s switch to mlmmj-{,un}sub to control whether or not to
  send a mail telling about already subscribed, or not subscribed
  when trying to subscribe or unsubscribe
* Fri Jun  3 2005 mmj@suse.de
- Make sure FastTemplate is GPL
* Thu May 12 2005 mmj@suse.de
- Update to 1.2.7 which fixes another couple of bugs:
  o Remove old superflous cruft in the smtpreply reader function,
  making mlmmj-send not segfault in rare cases when SIGTERM was sent
  o Another printf had snuck in there printing a free'ed variable
* Mon May  9 2005 mmj@suse.de
- Update to 1.2.6.1 which is a bugfix release:
  o Make sure the fromaddr is correct on sub-subscribed mails
  o Don't add an empty subject if there was one present
* Sun May  8 2005 mmj@suse.de
- Update to 1.2.6 including:
  o If prefix but no Subject: header is present, add one
  o Add notification mail when subbed people try to sub
  o Install SIGTERM handler in mlmmj-send to allow it to shut down
  gracefully
  o Also remove mails when it's a bounce from a person not subbed
  o Introduce read() wrapper
  o Bouncing confirmation mails of sub or unsub should be cleaned
  from the queue as well
  o Normally mails which doesn't have exactly one From:
  emailaddress are discarded but certain ISPs have bounce mails
  with no From: header, forcing us to allow bounce mails with no
  From: to make sure they're caught
  o In case of a succesful DSN parse, we werent deleting the mail,
  and thus littering the queue
  o When sending moderated mails, rename them so that they wont be
  moderated again while sending
* Sun May  1 2005 mmj@suse.de
- Enable parallel build
- Add patch to fix possible race condition wrt. moderation
* Tue Apr 26 2005 mmj@suse.de
- Update to 1.2.5 including:
  o Make listname+list send the list of regular subscribers to the
  owner who requested it.
  o Michael Fleming corrected some spelling / grammatical errors
  and made occasional minor clarifications in the english list
  texts.
  o Add README.sendmail from Andrea Barisani
  o Add README.exim4 from Jakob Hirsch
  o Skip addresses without a @ when sending
  o Set SO_KEEPALIVE for our connection socket
* Mon Feb 14 2005 mmj@suse.de
- Update to 1.2.4 including:
  o Spend some time making valgrind completely happy
  o Unlink totally harmless .lock files in subscribers dir
  o Make it possible to specify more than one listaddress in
  LISTDIR/control/listaddress. The first one is the "real" one
  o Make the port to connect to controlable with DIR/control/smtpport
* Tue Feb  8 2005 mmj@suse.de
- Update to 1.2.3 including:
  o Only allow subscription of addresses with '@' in them
  o Fix return value from unsubscribe function
  o Add extra lock layer when accessing subscribers files
  o In case of listname+bounces-INDEX use the DSN (RFC1891) report
  to extract the bouncing address
  o Fix usage of a zero sized control/verp string
  o Make the Date: header RFC2822 conformant
* Tue Feb  1 2005 mmj@suse.de
- Update to 1.2.2 including:
  o Make mlmmj-send work allthough no subscribers exist
  o Bring webinterfaces up to speed
  o Fix moderate tag in access
  o Make mlmmj-make-ml.sh default the listtext dir to where they were
  installed in the system
* Wed Jan 26 2005 mmj@suse.de
- Update to 1.2.1 including:
  o Introduce switches to turn off mails about posts being denied
* Sun Jan 23 2005 mmj@suse.de
- Update to mlmmj-1.2.0 with the only difference since RC2 being
  a debug info removed.
* Tue Jan 18 2005 mmj@suse.de
- Update to 1.2.0-RC2 including since 1.2.0-RC1:
  o Fix uninitialized strlist
  o Add logging regular operation to mlmmj.operation.log
  o Fix the sending loop by not sending the rest of the batch in every
  iteration
* Sun Jan 16 2005 mmj@suse.de
- Update to 1.2.0-RC1 including since 1.1.1-RC1:
  o Add VERP support.
  o It's ok to log to a symbolic link to somewhere else
  o Add Message-Id: and Date: headers to mail from mlmmj
  o Make log_oper() varargs capable
* Thu Jan 13 2005 mmj@suse.de
- Update to 1.1.1-RC1 including since 1.1.0:
  o Never discard anything from LISTDIR/queue/, let the admin be able
  to judge
  o Grab the lock when sending a mail to make sure noone does bad things
  to it underneath us
  o Danish listtexts
  o Add control/noget to turn of listname+get-INDEX
  o Rearrange envelope from to be listname+bounces-index-user=domain.tld(at)
  instead of listname+bounces-user=domain.tld-index(at) to prepare
  for VERP support
* Wed Dec  1 2004 mmj@suse.de
- It's text.skel now, not listtexts
* Mon Nov 29 2004 mmj@suse.de
- Update to 1.1.0 including since RC3:
  o If mlmmj-recieve was invoked with a uid not root or not the owner
  of listdir inform about the uid actually invoked with
  o Add German listtexts
  o Add hooks for installing listtexts into $(pkgdatadir)
  o Add mlmmj-list manual page
  o Make mlmmj-list be capable of listing owners, moderators too
  o Perl interface updates
* Thu Nov 25 2004 mmj@suse.de
- Update to 1.1.0-RC3 including since RC2:
  o Add 'moderate' tag for usage in control/access when one wants to
  have the moderators moderate posts hitting this regexp.
  See README.access
  o Add a To: header with the recipient's address when sending digests
* Mon Nov 22 2004 wimer@suse.de
- Update to 1.1.0-RC2 including since RC1:
  o Strip envelope from before resending to +owner
  o Make statctrl bail if it's not possible to stat()
  o Add mlmmj-list binary to list the subcribers (-count) of a list
* Fri Nov 12 2004 mmj@suse.de
- Update to 1.1.0-RC1 including since 1.1.0:
  o Rewrite the way listtexts are managed, and in the process move
  the Subject: out into the listtext file making mlmmj
  completely translateable
  o Enhance perl webinterface - including group writable patch
  o Add option control/nosubconfirm which makes it possible to
  subscribe without confirmation by just sending the mail
  o Make files discarded by maintd end in .by-maintd to make them
  distinct
  o Fix off-by-one error in the function cleaning quoted printable
  chars
  o Close the correct fd's in mlmmj-process
  o Be consistent when using To: or Delivered-To:
  o mlmmj-unsub should also change user id to the listdir owner
  o Add support for not archiving the list by touching
  listdir/control/noarchive
  o Add 'nomail' version of lists. Subscribers to the nomail
  version are subscribed, but does not get any mail
  o Don't talk about changing uid in mlmmj-sub when we're not
  really doing it
  o Add sanity checks to disallow denial mails going to the list
  o Add digest functionality
  o Implement -d option for mlmmj-maintd to be able to supply it
  with a directory containing several listdirs, where mlmmj-maintd
  then will run maintenance
  o Chown option and a fix for mlmmj-make-ml.sh
* Wed Sep  8 2004 mmj@suse.de
- Update to 1.0.0 including since RC4:
  o Replace index() with strchr()
  o Add parenthesis around realloc call to make sure we alloc
  correctly
  o Make header matching case insensitive
  o Fix dumping of addresses to requeue
  o Make the time an address can bounce before unsubscribed
  configurable with listdir/control/bouncelife
  o Correct mlmmj-make-ml.sh cronentry line to include -F
  o Add manual pages
  o Make random numbers lowercase hex since gmail is lowercasing
  the address it replies to
  o Also make sanity check in mlmmj-maintd to ensure it's invoke
  either as root or as listdir owner
* Wed Sep  1 2004 mmj@suse.de
- Update to 1.0.0-RC4 fixing a brown paper bag bug
* Wed Sep  1 2004 mmj@suse.de
- Update to 1.0.0-RC3 including:
  o NULL and 0 are not the same on 64-bit platforms, so fix
  execlp(..., 0); to be execlp(..., NULL);
  o Add web-interface (PHP)
  o Have the random numbers be somewhat longer everywhere and not
  just somewhere
  o Move free() to where it belongs
  o Fix printing of cron entry in mlmmj-make-ml.sh
* Wed Aug 25 2004 mmj@suse.de
- Update to 1.0.0-RC2 including:
  o Do not allow mails from <> going to the list
  o Fix mailing to +owner again by adding missing 'break;' to switch in
  mlmmj-send
  o perl-admin and php-user updates
  o Use Delivered-To: instead of To: when available
* Sat Aug 21 2004 mmj@suse.de
- Update to 1.0.0-RC1 including:
  o Add web-interface
  o Dump the customheaders before any Mime headers
  o Implement +get-N functionality, so it's possible to send a mail to
  foolist+get-101@domain.tld to retrieve mail 101 from that list. It's
  deliberately only possible to request one mail at a time.
  o Make sure that only either root or the listdir owner can execute the
  binaries when it has something to do with lists.
  o Dont leave bounces-help mails lying around in queue
  o Remove unanchored ".*" from beginning of regexp
* Wed Aug 11 2004 mmj@suse.de
- Update to 0.8.3 including:
  o Have mlmmj-make-ml.sh remind people about using cron if they want
  o Replying to the confirmation address is enough to sub/unsub, no
  matter what address is used the second time
  o Fix possible DoS wrt. unsubscribing.
  o Add 'notifysub' functionality to have owner know when people
  sub/unsub.
  o Use Return-Path: for envelope From.
  o Specification of which relayhost to use can now be done in
  control/relayhost
  o Add configure check to link against libnsl if needed.
  o Implement our own daemon() function since we don't have daemon()
  on Solaris
* Sat Jul  3 2004 mmj@suse.de
- Update to 0.8.2 including:
  o Make sure we don't cut of the first char of an emailaddress
  o Fix header value copying
  o Don't segfault if there's no email address in the To: header
  o Clean up the subconf and unsubconf directories for stale requests
  as well
* Mon Jun 28 2004 mmj@suse.de
- Update to 0.8.1.1 including:
  o Fix bug with prepstdreply not opening correct file.
  o Go through all open() calls and retry in case we (allthough it's extremely
  unlikely) did get EEXIST
  o Add the option to add a To: header including the recipient emailaddress.
  NOTE that this does not remove any existing To: headers, they should be
  removed in control/delheaders
  o Optimize mlmmj-send by preparing the mail in memory to reduce the amount of
  write syscalls. control/memmailsize (size in bytes) controls how big it can
  be. Default is 16k before it's send line by line.
  o Make sure we check if the Subject: prefix might be present in the
  de-quoted printable version of the Subject. If so, don't add it.
  o Fix bug with queuefilename not being correctly initialized when generating
  standard mails
  o Let mlmmj-send be capable of handling relayhost local users bounce probes
  bouncing.
  o Don't litter the queuedirectory with files when rejecting mails (the
  maintenance daemon would take care of it, but lets be nice)
* Mon Jun 21 2004 mmj@suse.de
- Make mlmmj-make-ml.sh be aware of where we install the listtexts
- Update to 0.8.0 including:
  o Added regular expression based access control.
  o Added wrappers for malloc(), realloc(), free() and strdup(), so we can
  bail out if any of them fail.
* Thu Jun 17 2004 mmj@suse.de
- Update to 0.7.3 including:
  o Implement control/delheaders in where one can specify all the headers
  to delete in incoming mail to the list.
  o Add +owner functionality (control/owner). Several addresses possible.
  o Relicense the whole thing to be MIT instead of GPL
* Mon Jun 14 2004 mmj@suse.de
- Update to 0.7.2 including:
  o Make it possible to only let subscribers post
  o Implement feature to deny posts where the listaddress is not in To: or
  Cc:. Enabled pr. default, but can be disabled by touching control/tocc
  o Make mlmmj-sub change uid to the owner of listdir to avoid permission
  problems. Disable with -U to mlmmj-sub.
  o More memory debugging
* Thu Jun 10 2004 mmj@suse.de
- Update to 0.7.1 which is a bugfix release
* Wed Jun  9 2004 mmj@suse.de
- Update to 0.7.0 including:
  o Add a macro to make sure mlmmj binaries are invoked with full path
  o Add the function to mlmmj-maintd to unsubscribe people who've been
  bouncing for BOUNCELIFE (default 432000 sec, 5 days) time.
  This completes the bouncehandling of mlmmj.
  o Add logging to mlmmj-maintd. mlmmj-maintd.lastrun.log in the listdir
  always has the log of the last run. This is work in progress.
  o Make mlmmj-bounce capable of sending probes
  o Include a function for easy generation of standard mail replies
* Sun Jun  6 2004 mmj@suse.de
- Update to 0.6.0 including:
  o Add several unlinks. No need to litter queue/ with useless files
  o Don't use moderation/queue for outgoing, just use queue/
  o Christoph Thiel pointed out that listaddress and moderators belong in
  control/ so move them there
  o Get rid of all FILE * instances and replace them with fd's
  o Also mmap the subscribers file when reading subcribers
  o Do an mmap of the mail to send once, instead of reading the mail for
  each mail to send
  o Rip out the ability to fork to make more than one connection to relayhost.
  It turned out to not make any performance gain (tested with lists with
  more than 120000 subscribers), and thus only complicated things.
  KISS won, so it's gone.
  o mlmmj-maint now handles resends and cleanup
  o Fixed interrupted fgets() in write_mailbody_from_file()
  o Fixed leak of subfile in mlmmj-send
* Sat May 29 2004 mmj@suse.de
- Update to 0.5.2 including:
  o footer and customheaders are now accessed from listdir/control/ where
  they belong
  o Discard mails that doesn't have one and only one From: address. Discard
  here means moving them to queue/discard
  o Make sure we retrieve info from all headers matching the token we want
  o Fixed error handling in mlmmj-send if we can not open subscribers.d/
  o Make mlmmj-send a lot more robust with SMTP and handle
  bounces from the relayhost.
  o Fix BUG in mlmmj-bounce still using listdir/subscribers
  o Handle subconf/unsubconf bounces
  o Begin work on mlmmj-maintd--the mlmmj maintenance daemon
  o Make help consistent and up to date with all options
  o Make mlmmj-send print the replies from the mailserver
  o Send our hostname in the HELO instead of relayhost
  o Implement requeueing mechanism to be able to resend mail when relayhost
  trouble occur
* Wed May 19 2004 mmj@suse.de
- Update to 0.5.1 which main focus is subject prefix. A few
  bugfixes as well, and a bit of docu.
* Tue May 18 2004 mmj@suse.de
- Update to 0.5.0 including:
  o Use a subscribers.d/ directory for several subscribers files.
  mlmmj-send will now fork for each file (up to MAX_CONNECTIONS)
  for faster delivery.
  mlmmj-unsub will search for subscribers in all of these files.
  mlmmj-sub will now add emailaddresses to the file in subscribers.d/
  with the name of the first character in the emailaddress
  (foo@bar.com will be in subscribers.d/f).
  o Major cleanup of listcontrol() and in the process add closed list
  functionality (touch listdir/control/closedlist and it's closed)
* Mon May 10 2004 mmj@suse.de
- Initial package, mlmmj-0.4.0
